package com.jsliders.puble;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class PubleDatabaseProvider 
{   
    private static final String TAG = "DBAdapter";
    private static final String DATABASE_NAME = "puble";
    private static final int DATABASE_VERSION = 25;

    private static final String DATABASE_CREATE_RESTAURANT =
        "create table restaurant (_id integer primary key autoincrement, "
        + "Name text not null, Address text not null,Postalcode text not null, " 
        + "City text not null, Phone text not null, "
        + "Email text not null, MaxCustomers int not null,Openhours text,RestaurantType text);";
    
    private static final String DATABASE_CREATE_PROGRAMME =
        "create table programme (_id integer primary key autoincrement, "
        + "rid integer not null, Date date not null, Showtime time not null, "
        + "Cost integer not null, Description text not null);";
    
    private static final String DATABASE_CREATE_MENU =
        "create table menu (_id integer primary key autoincrement, "
        + "rid integer not null, Name text not null, " 
        + "Description text not null, Price double not null);";
    
    private static final String DATABASE_CREATE_OFFERS =
        "create table offers (_id integer primary key autoincrement, "
        + "rid integer not null, Description text not null, StartTime text not null,EndTime text not null" 
        + ");";
    
    private static final String DATABASE_CREATE_CUSTOMERCOUNT =
        "create table customercount (_id integer primary key autoincrement, "
        + "rid integer not null, Counter integer not null, Direction integer not null," 
        + "Date date not null, Time time not null);";
    private final Context context; 
    
    private DatabaseHelper DBHelper;
    private SQLiteDatabase db;

    public PubleDatabaseProvider(Context ctx) 
    {
        this.context = ctx;
        DBHelper = new DatabaseHelper(context);
    }
        
    private static class DatabaseHelper extends SQLiteOpenHelper 
    {
        DatabaseHelper(Context context) 
        {
            super(context, DATABASE_NAME, null, DATABASE_VERSION);
        }

        @Override
        public void onCreate(SQLiteDatabase db) 
        {
            db.execSQL(DATABASE_CREATE_RESTAURANT);
            db.execSQL(DATABASE_CREATE_CUSTOMERCOUNT);
            db.execSQL(DATABASE_CREATE_PROGRAMME);
            db.execSQL(DATABASE_CREATE_MENU);
            db.execSQL(DATABASE_CREATE_OFFERS);
        }

        @Override
        public void onUpgrade(SQLiteDatabase db, int oldVersion, 
        int newVersion) 
        {
            Log.w(TAG, "Upgrading database from version " + oldVersion 
                    + " to "
                    + newVersion + ", which will destroy all old data");
            db.execSQL("DROP TABLE IF EXISTS restaurant");
            db.execSQL("DROP TABLE IF EXISTS customercount");
            db.execSQL("DROP TABLE IF EXISTS programme");
            db.execSQL("DROP TABLE IF EXISTS offers");
            db.execSQL("DROP TABLE IF EXISTS menu");
            onCreate(db);
            
            db.execSQL("INSERT INTO restaurant (name,address,postalcode,city,phone,email,maxcustomers,openhours,RestaurantType) values ('Lucky Monkeys', 'Valtakatu 42','53100' ,'Lappeenranta', '555-Olutta', 'lucky@monkeys.com', 100,'MA - \nTI -\nPE 22 - 02\n',1)");
            db.execSQL("INSERT INTO restaurant (name,address,postalcode,city,phone,email,maxcustomers,openhours,RestaurantType) values ('Ravintola Totem', 'Raatimiehenkatu 17','53100' ,'Lappeenranta', '', '', 50,'MA - \nTI -\nPE 22 - 02\n',1)");
            db.execSQL("INSERT INTO restaurant (name,address,postalcode,city,phone,email,maxcustomers,openhours,RestaurantType) values ('Giggling Marlin', 'Oksasenkatu 2','53100','Lappeenranta', '020 775 9840', 'xxx.xxx@yyy.com', 100,'',2)");
            db.execSQL("INSERT INTO restaurant (name,address,postalcode,city,phone,email,maxcustomers,openhours,RestaurantType) values ('Ravintola Wiltsu', 'Kauppakatu 39','53100','Lappeenranta', '05 541 1280', 'xxx.xxx@aaa.com', 150,'',2)");
            db.execSQL("INSERT INTO restaurant (name,address,postalcode,city,phone,email,maxcustomers,openhours,RestaurantType) values ('Ravintola Raittinen', 'Sammontori 2','53850','Lappeenranta', '0107621492', 'toni.rosenholm@kolumbus.fi', 50,'',1)");

                        
            //Tajoukset
            db.execSQL("INSERT INTO offers (rid,Description,starttime,endtime) VALUES (1,'Karhu 0.5l Olut 2','19.03.2010','19.04.2010')");
            db.execSQL("INSERT INTO offers (rid,Description,starttime,endtime) VALUES (1,'Sidukka 0.4l 6','19.03.2010','20.03.2010')");
            db.execSQL("INSERT INTO offers (rid,Description,starttime,endtime) VALUES (2,'KOFF 0.5l Olut 2.5','19.03.2010','19.04.2010')");
            db.execSQL("INSERT INTO offers (rid,Description,starttime,endtime) VALUES (3,'Hanatuotteet 10','19.03.2010','21.03.2010')");
            
            //Menu
            db.execSQL("INSERT INTO menu (rid,name,description,price) VALUES (1,'Konjakki','Leikattu',6.9)");
            db.execSQL("INSERT INTO menu (rid,name,description,price) VALUES (1,'Salmari','',2.5)");
            
            db.execSQL("INSERT INTO menu (rid,name,description,price) VALUES (2,'Suolaphkint','100g. Ei listty suolaa',2)");
            db.execSQL("INSERT INTO menu (rid,name,description,price) VALUES (2,'GT','Gin&Tonic',4.2)");
            
            //Programme
            db.execSQL("INSERT INTO programme (rid,Date,Showtime,Cost,Description) VALUES (1,'13.04.2010','20:00',5,'w/ Popeda and Klamydia')");
            db.execSQL("INSERT INTO programme (rid,Date,Showtime,Cost,Description) VALUES (2,'15.05.2010','21:00',6,'w/ Kari Tampio')");
            db.execSQL("INSERT INTO programme (rid,Date,Showtime,Cost,Description) VALUES (1,'06.06.2010','22:00',4,'w/ Kantri Heluna')");
            db.execSQL("INSERT INTO programme (rid,Date,Showtime,Cost,Description) VALUES (2,'13.07.2010','23:00',3,'w/ Iron Maiden')");
            
            //CustomerCounts
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'12.03.2010','23:45')");

            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'13.03.2010','23:45')");

            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'14.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'14.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'14.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'14.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'14.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'14.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'14.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'14.03.2010','23:45')");


            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'15.03.2010','23:45')");


            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'16.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'16.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'16.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'16.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'16.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'16.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'16.03.2010','23:45')");



            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'17.03.2010','23:45')");

            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'18.03.2010','23:45')");

            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
            db.execSQL("INSERT INTO customercount (rid,Counter , Direction ,Date, Time) VALUES (1,1,1,'19.03.2010','23:45')");
        }
    }    
    
    //---opens the database---
    public PubleDatabaseProvider open() throws SQLException 
    {
        db = DBHelper.getWritableDatabase();
        return this;
    }

    //---closes the database---    
    public void close() 
    {
        DBHelper.close();
    }
    
    public long insert(String table, ContentValues values){
    	long retVal = -1;
    	open();
    	retVal = db.insert(table, null, values);
    	close();
    	return retVal;
    }
    
    public boolean delete(String table, String rowID){
    	return db.delete(table, rowID, null) > 0;
    }
    
    public Cursor rawQuery(String sql, String[] selectionArgs){
    	Cursor retVal;
    	
    	open();
    	retVal = db.rawQuery(sql, selectionArgs);
    	close();
    	
    	return retVal;
    	
    }
    
    public Cursor query(String table, String[] columns, String selection, 
    		String[] selectionArgs, String groupBy, String having, String orderBy)  
    		throws SQLException 
    {
    	open();
        Cursor retVal =
                db.query(table, columns, selection, selectionArgs, groupBy, having, orderBy);
        if (retVal != null) {
        	retVal.moveToFirst();
        }
        
        close();
        
        return retVal;
        
        
    }
}
